@@ -54,7 +54,8 @@ class DockerManager(object):
                 'server' : self.config.spark,
                 'client' : self.config.spark_client },
             'gluster': { 
-                'server' : self.config.gluster },
+                'server' : self.config.gluster,
+                'client' : self.config.mpi_client },
             'cassandra': { 
                 'server' : self.config.cassandra,
                 'client' : self.config.cassandra_client},
@@ -526,32 +527,22 @@ class DockerManager(object):
         """
         Create a new data directory
         """
-        # Check the location of the scratch directory. If not defined
-        # use the current directory
-        if 'FERRY_SCRATCH' in os.environ:
-            scratch_dir = os.environ['FERRY_SCRATCH'] + '/'
-        else:
-            scratch_dir = ''
+        scratch_dir = ferry.install._get_ferry_scratch()
 
         # First check if this data directory already exists. If so,
         # go ahead and delete it (this will hopefully get rid of all xattr stuff)
-        new_dir = scratch_dir + 'tmp/%s/data_%s' % (service_uuid, storage_type + '_' + str(storage_id))
+        new_dir = scratch_dir + '/%s/data_%s' % (service_uuid, storage_type + '_' + str(storage_id))
         return self._create_dir(new_dir, replace=True)
 
     def _new_log_dir(self, service_uuid, storage_type, storage_id, replace = False):
         """
         Create a new log directory
         """
-        # Check the location of the scratch directory. If not defined
-        # use the current directory
-        if 'FERRY_SCRATCH' in os.environ:
-            scratch_dir = os.environ['FERRY_SCRATCH'] + '/'
-        else:
-            scratch_dir = ''
+        scratch_dir = ferry.install._get_ferry_scratch()
 
         # First check if this data directory already exists. If so,
         # go ahead and delete it (this will hopefully get rid of all xattr stuff)
-        new_dir = scratch_dir + 'tmp/%s/log_%s' % (service_uuid, storage_type + '_' + str(storage_id))
+        new_dir = scratch_dir + '/%s/log_%s' % (service_uuid, storage_type + '_' + str(storage_id))
         return self._create_dir(new_dir, replace=replace)
 
     def _create_dir(self, new_dir, replace=False):
@@ -595,7 +586,11 @@ class DockerManager(object):
         """
         Read the directory containing the key we should use. 
         """
-        with open(ferry.install.DEFAULT_DOCKER_KEY, 'r') as f:
+        # This needs to be fixed. When starting the
+        # container, we need to know which key is being used. 
+        # However, we want to read the client directory instead of
+        # the server directory!
+        with open(ferry.install._get_key_dir(root=False, server=False), 'r') as f:
             k = f.read().strip().split("://")
             return { '/service/keys' : k[1]  }
 
@@ -954,7 +949,7 @@ class DockerManager(object):
         Start the service.
         """
         service_info = self._get_service_configuration(uuid, detailed=True)
-        self._start_service(uuid, containers, service_info)
+        return self._start_service(uuid, containers, service_info)
 
     def allocate_compute(self,
                          compute_type, 
@@ -1009,13 +1004,17 @@ class DockerManager(object):
                        service_info): 
         if service_info['class'] != 'connector':
             service = self._get_service(service_info['type'])
-            service.start_service(containers, service_info['entry'], self.docker)
+            return service.start_service(containers, service_info['entry'], self.docker)
         else:
             storage_entry = service_info['storage']
             compute_entry = service_info['compute']
             services, backend_names = self._get_client_services(storage_entry, compute_entry)
+            all_output = {}
             for service in services:
-                service.start_service(containers, service_info['entry'], self.docker)
+                output = service.start_service(containers, service_info['entry'], self.docker)
+                if output:
+                    all_output = dict(all_output.items() + output.items())
+            return all_output
 
     def _restart_service(self,
                          uuid,
@@ -1025,12 +1024,16 @@ class DockerManager(object):
         entry_point = service_info['entry']        
         if service_info['class'] != 'connector':
             service = self._get_service(service_type)
-            service.restart_service(containers, entry_point, self.docker)
+            return service.restart_service(containers, entry_point, self.docker)
         else:
+            all_output = {}
             for backend in service_info['backends']:
                 if 'client' in self.service[backend]:
                     service = self.service[backend]['client']
-                    service.restart_service(containers, entry_point, self.docker)
+                    output = service.restart_service(containers, entry_point, self.docker)
+                    if output:
+                        all_output = dict(all_output.items() + output.items())
+            return all_output
 
     def _stop_service(self,
                       uuid,
